Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: include/v8.h

Issue 2867863002: Rename idle garbage collection callback flag. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 4446b87e1c2a739c3f68a6da4eb64a48ec54e36b..ee51cc20447909467f7a241a4932cb2be31526b6 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -6186,7 +6186,7 @@ enum GCType {
* - kGCCallbackFlagCollectAllAvailableGarbage: The GC callback is called
* in a phase where V8 is trying to collect all available garbage
* (e.g., handling a low memory notification).
* - kGCCallbackScheduleIdleCollectGarbage: The GC callback is called to
* trigger an idle garbage collection.
*/
enum GCCallbackFlags {
@@ -6196,7 +6196,7 @@ enum GCCallbackFlags {
kGCCallbackFlagSynchronousPhantomCallbackProcessing = 1 << 3,
kGCCallbackFlagCollectAllAvailableGarbage = 1 << 4,
kGCCallbackFlagCollectAllExternalMemory = 1 << 5,
- kGCCallbackScheduleIdleCollectGarbage = 1 << 6,
+ kGCCallbackScheduleIdleGarbageCollection = 1 << 6,
};
typedef void (*GCCallback)(GCType type, GCCallbackFlags flags);
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -6186,7 +6186,7 @@ enum GCType {
* in a phase where V8 is trying to collect all available garbage
* (e.g., handling a low memory notification).
- * - kGCCallbackScheduleIdleCollectGarbage: The GC callback is called to
+ * - kGCCallbackScheduleIdleGarbageCollection: The GC callback is called to
* trigger an idle garbage collection.
*/

Powered by Google App Engine
This is Rietveld 408576698